<?php

namespace App\Http\Controllers\Api\V1;

use Illuminate\Http\Request;
use App\Http\Resources\CompetitorResource;
use App\Http\Controllers\Controller;
use App\Competitor;

class CompetitorsController extends Controller
{
    /**
     * Gets a single competitor
     *
     * @return Competitor Object
     * @author mattsidjohn
    **/
    public function get(Competitor $competitor)
    {
        return new CompetitorResource(
            $competitor->with('products')
                ->where('id', $competitor->id)
                ->get()
        );
    }

    /**
     * Get all competitors
     *
     * @return Competitors Object
     * @author mattsidjohn
     **/
    public function getAll()
    {
        return new CompetitorResource(
            Competitor::with('products')->get()
        );
    }

    /**
     * Store new Competitor.
     *
     * @return New Competitor Object
     * @author mattsidjohn
     **/
    public function store(Request $request)
    {
        // Create the new competitor
        $competitor = Competitor::create($request->all());

        return new CompetitorResource($competitor);
    }

    /**
     * Destroy the specified Competitor
     *
     * @return boolean
     * @author mattsidjohn
     **/
    public function destroy(Competitor $competitor)
    {
        try {
            // Delete the competitor
            $competitor->delete();

            return response('Success!', 200);
        } catch (Exception $e) {
            return response($e->getMessage, $e->code);
        }
    }
}
