<?php

namespace App\Http\Controllers\Api\V1;

use Auth;
use Illuminate\Http\Request;
use App\Product;
use App\Http\Controllers\Controller;
use App\Http\Resources\ProductResource;

class ProductController extends Controller
{

    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    /**
     * Gets the requested product.
     *
     * @return Specified Product
     * @author mattsidjohn
     **/
    public function get(Product $product)
    {
        // Handle Eager Loading
        if ($this->request->has('with')) {
            // Turn with query string into an array to specify eagerloads.
            $with = explode(':', $this->request->with);

            // Return the product with eager loaded objects.
            $product = $product
                ->with($with)
                ->where('products.id', $product->id)
                ->get();
        }

        return new ProductResource($product);
    }

    /**
     * Get all products
     *
     * @return Returns all the products in the system
     * @author mattsidjohn
     **/
    public function getAll()
    {
        // Handle Eager Loading
        if ($this->request->has('with')) {
            // Turn with query string into an array to specify eagerloads.
            $with = explode(':', $this->request->with);

            // Return the product with eager loaded objects.
            $products = Product::with($with)
                ->get();
        } else {
            $products = Product::all();
        }
        return new ProductResource($products);
    }
}
