<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Resources\UserResource;
use App\PlayerId;
use Auth;
use App\User;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;

class UserController extends Controller
{
    /**
     * Return the Authorized user.
     *
     * @return Authorized User
     * @author mattsidjohn
     **/
    public function get(Request $request)
    {
        return new UserResource(
            Auth::user()
                ->with(['roles', 'salesReps', 'salesManagers', 'playerIds'])
                ->where('id', Auth::user()->id)
                ->get()
        );
    }

    /**
     * Update the user with the given request.
     *
     * @return Updated User
     * @author mattsidjohn
     **/
    public function update(Request $request)
    {
        // Add player idea to the user
        if ($request->has('player_id')) {
            $playerId = PlayerId::firstOrCreate([
                'user_id' => Auth::user()->id,
                'player_id' => $request->player_id,
            ]);
        }

        // Update the user with the request
        Auth::user()->update($request->all());

        // Return updated user
        return new UserResource(
            Auth::user()
                ->with('roles')
                ->where('id', Auth::user()->id)
                ->get()
        );
    }

    public function store(Request $request)
    {
      $validator = Validator::make($request->input(), [
          'name' => 'required|string|max:255',
          'email' => 'required|string|max:255|unique:users',
          'company_name' => 'required|string|max:255|unique:users',
          'password' => 'required|string|min:6|confirmed',
          'password_confirmation' => 'required|string|min:6|',
      ]);

      if ($validator->fails()) {
          return json_encode($validator->errors()->all());
      } else {
          $user = User::create([
              'name' => $request['name'],
              'email' => $request['email'],
              'company_name' => $request['company_name'],
              'password' => bcrypt($request['password']),
              'password_confirmation' => bcrypt($request['password_confirmation']),
          ]);

          $user->assignRole('sales rep');

          $token = $user->createToken($request->reference ?? 'General')->accessToken;
          $user->update(['api_token' => $token]);

          return ['data' => ['bearer_token' => $user->api_token, 'success' => true]];
      }
    }
}
