<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Competitor;
use App\CompetitorProduct;
use App\ProductVariation;
use App\Services\DataTablesService;

class CompetitorProductsController extends Controller
{
    public function __construct(DataTablesService $dataTables)
    {
        $this->dataTables = $dataTables;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Competitor $competitor)
    {
        if (request()->ajax()) {
            return $this->dataTables->handle('competitorProducts', $competitor, $request);
        }

        return view('competitors.products.index', [
            'competitor' => $competitor,
            'products' => $competitor->products
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('competitors.products.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Competitor $competitor)
    {
        return redirect()->back()->with('success', 'The competitor product has been successfully created!');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Competitor $competitor, CompetitorProduct $competitorProduct)
    {
        return view('competitors.products.show', [
            'competitorProduct' => $competitorProduct
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Competitor $competitor, CompetitorProduct $product)
    {
        return view('competitors.products.edit', [
            'competitor' => $competitor,
            'product' => $product,
            'napcoVariations' => ProductVariation::all()
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Competitor $competitor, CompetitorProduct $product)
    {
        $product->update($request->all());
        return redirect()->back()->with('success', 'The competitor product has been successfully updated!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Competitor $competitor, CompetitorProduct $competitorProduct)
    {
        $competitorProduct->delete();
        return redirect()->back()->with('success', 'The competitor product has been successfully deleted!');
    }
}
