<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class ProductVariation extends Model
{
    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'product_variations';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'product_id',
        'item_relationship',
        'item_number',
        'material_category',
        'material_type',
        'gallon_capacity',
        'width',
        'length',
        'bag_gauge',
        'color',
        'case_count',
        'rolls_bags',
        'max_dry_load',
        'skid_count',
        'case_weight',
        'ply',
    ];

    /**
     * Function to return related item
     *
     * @return object of item
     * @author @mattsidjohn
     **/
    public function item()
    {
        return $this->belongsTo(ProductItem::class);
    }

    /**
     * Function to return related product
     *
     * @return object of product
     * @author @mattsidjohn
     **/
    public function product()
    {
        return $this->belongsTo(Product::class);
    }

    /**
     * Competitor Relationship
     *
     * @return Competitor Object
     * @author mattsidjon
     **/
    public function competitorProducts()
    {
        return $this->belongsToMany(
            CompetitorProduct::class,
            'product_variations_competitor_products',
            'variation_id',
            'competitor_product_id'
        );
    }
}
