<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class Quote extends Model
{
    /**
     * The models mass assignable attributes
     *
     * @var array
     */
    protected $fillable = [
        'image',
        'details',
        'sales_manager_id',
        'status'
    ];

    /**
     * Sales Manager Relationship
     *
     * @return Sales Manager Object
     * @author mattsidjohn
     **/
    public function salesManager()
    {
        return $this->belongsTo(
            User::class,
            'sales_manager_id'
        );
    }

    /**
     * Sales Rep Relationship
     *
     * @return Sales Rep Object
     * @author mattsidjohn
     **/
    public function salesRep()
    {
        return $this->belongsTo(
            User::class,
            'sales_rep_id'
        );
    }

    /**
     * Chat Message Relationship
     *
     * @return Object of Messages
     * @author mattsidjohn
     **/
    public function chatMessages()
    {
        return $this->morphMany(
            ChatMessage::class,
            'chatable'
        );
    }

    /**
     * Files Relationship
     *
     * @return Object of Files
     * @author mattsidjohn
     **/
    public function files()
    {
        return $this->morphMany(
            File::class,
            'filable'
        );
    }
}
