<?php

namespace App;

use Laravel\Passport\HasApiTokens;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;

class User extends Authenticatable
{
    use HasApiTokens, Notifiable, HasRoles;

    protected $fillable = [
        'name',
        'email',
        'password',
        'company_name',
        'phone_number'
    ];

    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * Sales Rep Relationship
     *
     * @return void
     * @author mattsidjohn
     **/
    public function salesReps()
    {
        return $this->belongsToMany(
            User::class,
            'user_users',
            'sales_manager_id',
            'sales_rep_id'
        );
    }

    /**
     * Sales Rep Relationship
     *
     * @return void
     * @author mattsidjohn
     **/
    public function salesManagers()
    {
        return $this->belongsToMany(
            User::class,
            'user_users',
            'sales_rep_id',
            'sales_manager_id'
        );
    }

    /**
     * Rep Quotes Relationship
     *
     * @return Rep Quotes Object
     * @author mattsidjohn
     **/
    public function repQuotes()
    {
        return $this->hasMany(
            Quote::class,
            'sales_rep_id'
        );
    }

    /**
     * Manger Quotes Relationship
     *
     * @return Manger Quotes Object
     * @author mattsidjohn
     **/
    public function managerQuotes()
    {
        return $this->hasMany(
            Quote::class,
            'sales_manager_id'
        );
    }

    /**
     * Message Relationship
     *
     * @return ChatMessages Object
     * @author mattsidjohn
     **/
    public function chatMessages()
    {
        return $this->hasMany(
            ChatMessage::class,
            'author_id'
        );
    }

    /**
     * Player ID Relationship
     *
     * @return PlayerId Object
     * @author ryandoss
     */
    public function playerIds()
    {
        return $this->hasMany(
            PlayerId::class,
            'user_id'
        );
    }
}
