<?php

namespace Tests\Feature;

use App\User;
use Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class AdminsCreatesUsersTest extends TestCase
{
    use DatabaseMigrations;

    public function setUp()
    {
        parent::setUp();
        $this->seed('RolesAndPermissionsSeeder');
        $this->admin = factory(User::class)->create();
        $this->admin->assignRole('administrator');
    }

    /** @test */
    public function admins_can_create_sales_reps()
    {
        $response = $this->actingAs($this->admin)
            ->post('/users', [
                'name' => 'Bob Test',
                'email' => 'bob@example.com',
                'password' => bcrypt('secret'),
                'role' => 'sales rep',
            ]);

        $user = User::where('email', 'bob@example.com')->first();
        $this->assertTrue($user->hasRole('sales rep'));
    }

    /** @test */
    public function admins_can_create_sales_managers()
    {
        $response = $this->actingAs($this->admin)
            ->post('/users', [
                'name' => 'Bob Test',
                'email' => 'bob@example.com',
                'password' => bcrypt('secret'),
                'role' => 'sales manager',
            ]);

        $user = User::where('email', 'bob@example.com')->first();
        $this->assertTrue($user->hasRole('sales manager'));
    }

    /** @test */
    public function admins_can_update_users()
    {
        $user = factory(User::class)->create([
            'email' => 'old@email.com'
        ]);

        $response = $this->actingAs($this->admin)
            ->post('/users/'.$user->id, [
                '_method' => 'PUT',
                'email' => 'new@email.com'
            ]);

        $updatedUser = User::where('email', 'new@email.com')->first();
        $this->assertNotEquals($user->email, $updatedUser->email);
    }

    /** @test */
    public function admins_can_delete_users()
    {
        $this->withoutMiddleware();
        $user = factory(User::class)->create([
            'email' => 'tobe@deleted.com',
        ]);
        $response = $this->actingAs($this->admin)
            ->post('/users/'. $user->id, [
                '_method' => 'DELETE',
            ]);
        $deletedUser = User::where('email', 'tobe@deleted.com')->first();
        $this->assertNull($deletedUser);
    }
}
